// App.js
import React from 'react';

import AppBar from '@mui/material/AppBar';
import IconButton from '@mui/material/IconButton';
import Toolbar from '@mui/material/Toolbar';
import Typography from '@mui/material/Typography';
import { Route, Router, Routes } from 'react-router-dom';
import ConfigContext, { config } from './Config';
import LoginForm from './LoginForm';
import Main from './Main';
import VideoPlayer from './VideoPlayer'; // 导入我们将创建的VideoPlayer组件
import { default as VuetifyLogo, default as VuetifyName } from './logo.svg';

import axios from 'axios';
import { useLocation, useNavigate } from 'react-router-dom';
 
axios.interceptors.request.use((config) => {
  const token = localStorage.getItem('token');
  if (token) {
    config.headers.Authorization = `Bearer ${token}`;
  }
  return config;
});

const App = () => {
  const navigate = useNavigate(); // 将 navigate 声明移动到组件内部
  const location = useLocation();

  axios.interceptors.response.use(
 
    (response) => {
      return response;
    },

    (error) => {
      

      if (error.response.status === 401) {
        sessionStorage.setItem('previousLocation', location.pathname); // 使用 window.location.pathname 获取当前路径
        navigate('/login'); // 使用 window.location.assign() 进行导航
      }
      return Promise.reject(error);
    }
  );

  return (


    <ConfigContext.Provider value={config}>
      
        <div>
          <AppBar position="static">
            <Toolbar>
              <IconButton edge="start" color="inherit" aria-label="menu">
                <img src={VuetifyLogo} alt="Vuetify Logo" width="40" />
              </IconButton>
              <Typography variant="h3" style={{ flexGrow: 1 }}>
                <img src={VuetifyName} alt="Vuetify Name" width="40" />
              </Typography>
            </Toolbar>
          </AppBar>
        </div>
        <Routes>
            <Route path="/login" element={<LoginForm />} />
            <Route path="/" element={<Main />} />
            <Route path="/res/:filename" element={<VideoPlayer />} />
        </Routes>

    </ConfigContext.Provider>

  );
};

export default App;